@@ -1,7 +1,7 @@
 /*
  *  editdlgtypes.cpp  -  dialogs to create or edit alarm or alarm template types
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -34,11 +34,10 @@
 #include "lib/radiobutton.h"
 #include "lib/shellprocess.h"
 #include "lib/timespinbox.h"
+#include "kalarmcalendar/identities.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/Identities>
-
-#include <Akonadi/Contact/EmailAddressSelectionDialog>
+#include <Akonadi/EmailAddressSelectionDialog>
 #include <KCalUtils/ICalDrag>
 #include <KCalendarCore/Person>
 
@@ -711,7 +710,7 @@ void EditDisplayAlarmDlg::slotDisplayMethodChanged(int index)
     // Because notifications automatically time out after 10 seconds,
     // auto-close would always occur after a notification closes.
     lateCancel()->showAutoClose(enable);
-    // Set the text message edit box colours according to the display metho according to the display methodd.
+    // Set the text message edit box colours according to the display method.
     setColours(mFontColourButton->fgColour(), mFontColourButton->bgColour());
 }
 
@@ -1593,6 +1592,12 @@ EditAudioAlarmDlg::EditAudioAlarmDlg(bool Template, const KAEvent& event, bool n
     connect(theApp(), &KAlarmApp::audioPlaying, this, &EditAudioAlarmDlg::slotAudioPlaying);
 }
 
+EditAudioAlarmDlg::~EditAudioAlarmDlg()
+{
+    if (mMessageWindow)
+        MessageDisplay::stopAudio();
+}
+
 /******************************************************************************
 * Return the window caption.
 */
