@@ -1,14 +1,14 @@
 /*
  *  eventlistview.h  -  base class for widget showing list of alarms
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2007-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
 
-#include <KAlarmCal/KAEvent>
+#include "kalarmcalendar/kaevent.h"
 
 #include <QTreeView>
 #include <QItemDelegate>
@@ -71,5 +71,4 @@ class EventListDelegate : public QItemDelegate
         virtual void edit(KAEvent&, EventListView*) = 0;
 };
 
-
 // vim: et sw=4:
