@@ -1,7 +1,7 @@
 /*
  *  functions.cpp  -  miscellaneous functions
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2001-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2001-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -26,11 +26,9 @@
 #include "lib/filedialog.h"
 #include "lib/messagebox.h"
 #include "lib/shellprocess.h"
-#include "config-kalarm.h"
+#include "kalarmcalendar/identities.h"
 #include "kalarm_debug.h"
-
-#include <kalarmcal_version.h>
-#include <KAlarmCal/Identities>
+#include "config-kalarm.h"
 
 #include <KCalendarCore/Event>
 #include <KCalendarCore/ICalFormat>
@@ -46,7 +44,14 @@ using namespace KCalendarCore;
 #include <KSharedConfig>
 #include <KToggleAction>
 #include <KLocalizedString>
+
+#include <kauth_version.h>
+#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
+#include <KAuth/ActionReply>
+#include <KAuth/ExecuteJob>
+#else
 #include <KAuth>
+#endif
 #include <KStandardShortcut>
 #include <KFileItem>
 #include <KJobWidgets>
@@ -1245,7 +1250,7 @@ QStringList checkRtcWakeConfig(bool checkEventExists)
         {
             Resource resource = Resources::resource(params[0].toLongLong());
             if (!resource.event(params[1]).isValid())
-                return QStringList();
+                return {};
         }
         return params;                   // config entry is valid
     }
@@ -1254,7 +1259,7 @@ QStringList checkRtcWakeConfig(bool checkEventExists)
         config.deleteEntry("RtcWake");   // delete the expired config entry
         config.sync();
     }
-    return QStringList();
+    return {};
 }
 
 /******************************************************************************
@@ -1484,7 +1489,7 @@ bool editAlarmById(const EventId& id, QWidget* parent)
 * Open the Edit Alarm dialog to edit the specified template.
 * If the template is read-only, the dialog is opened read-only.
 */
-void editTemplate(KAEvent& event, QWidget* parent)
+void editTemplate(const KAEvent& event, QWidget* parent)
 {
     if (eventReadOnly(event.id()))
     {
@@ -1667,7 +1672,7 @@ QString runKMail()
             return xi18nc("@info", "Unable to start <application>KMail</application><nl/>(<message>%1</message>)", errmsg);
         }
     }
-    return QString();
+    return {};
 }
 
 /******************************************************************************
@@ -1683,7 +1688,7 @@ QString runKMail()
 QStringList dontShowErrors(const EventId& eventId)
 {
     if (eventId.isEmpty())
-        return QStringList();
+        return {};
     KConfig config(QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + ALARM_OPTS_FILE);
     KConfigGroup group(&config, DONT_SHOW_ERRORS_GROUP);
     const QString id = QStringLiteral("%1:%2").arg(eventId.resourceId()).arg(eventId.eventId());
