@@ -1,7 +1,7 @@
 /*
  *  functions.h  -  miscellaneous functions
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2007-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2007-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -12,8 +12,7 @@
 
 #include "editdlg.h"
 #include "eventid.h"
-
-#include <KAlarmCal/KAEvent>
+#include "kalarmcalendar/kaevent.h"
 
 #include <QString>
 #include <QVector>
@@ -85,7 +84,7 @@ void                updateEditedAlarm(EditAlarmDlg*, KAEvent&, Resource&);
 void                viewAlarm(const KAEvent&, QWidget* parent = nullptr);
 void                editNewTemplate(EditAlarmDlg::Type, QWidget* parent = nullptr);
 void                editNewTemplate(const KAEvent& preset, QWidget* parent = nullptr);
-void                editTemplate(KAEvent&, QWidget* parent = nullptr);
+void                editTemplate(const KAEvent&, QWidget* parent = nullptr);
 void                execNewAlarmDlg(EditAlarmDlg*, const QDate& startDate = QDate());
 /** Create a "New From Template" QAction */
 KToggleAction*      createAlarmEnableAction(QObject* parent);
@@ -321,5 +320,4 @@ void                setSimulatedSystemTime(const KADateTime&);
 
 bool caseInsensitiveLessThan(const QString& s1, const QString& s2);
 
-
 // vim: et sw=4:
