@@ -9,9 +9,7 @@
 #pragma once
 
 #include "messagedisplayhelper.h"
-
-#include <KAlarmCal/KAEvent>
-
+#include "kalarmcalendar/kaevent.h"
 
 class KConfigGroup;
 class DeferAlarmDlg;
@@ -51,6 +49,9 @@ public:
     static void showError(const KAEvent& event, const DateTime& alarmDateTime,
                           const QStringList& errmsgs, const QString& dontShowAgain = QString());
 
+    MessageDisplay(const MessageDisplay&) = delete;
+    MessageDisplay& operator=(const MessageDisplay&) = delete;
+
     virtual ~MessageDisplay();
 
     bool isValid() const   { return mHelper->isValid(); }
@@ -193,5 +194,4 @@ private:
 friend class MessageDisplayHelper;
 };
 
-
 // vim: et sw=4:
