@@ -1,7 +1,7 @@
 /*
  *  fileresource.cpp  -  base class for calendar resource accessed via file system
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2006-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2006-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -13,10 +13,9 @@
 #include "singlefileresourceconfigdialog.h"
 #include "resources.h"
 #include "lib/autoqpointer.h"
+#include "kalarmcalendar/version.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/Version>
-
 #include <KLocalizedString>
 
 
@@ -72,7 +71,7 @@ QString FileResource::storageTypeString(bool description) const
             file = false;
             break;
         default:
-            return QString();
+            return {};
     }
     return storageTypeStr(description, file, mSettings->url().isLocalFile());
 }
@@ -368,7 +367,7 @@ void FileResource::loaded(bool success, QHash<QString, KAEvent>& newEvents, cons
         // This is only done when a delayed load fails.
         // If the resource previously loaded successfully, leave its events (in
         // mEvents) unchanged.
-        if (!success  &&  !errorMessage.isEmpty())
+        if (!errorMessage.isEmpty())
             Resources::notifyResourceMessage(this, MessageType::Error, xi18nc("@info", "Error loading calendar <resource>%1</resource>.", displayName()), errorMessage);
         return;
     }
