@@ -125,7 +125,7 @@ KAEvent ResourceType::event(const QString& eventId, bool allowDisabled) const
     if (it != mEvents.constEnd()
     &&  (allowDisabled || (it.value().category() & enabledTypes())))
         return it.value();
-    return KAEvent();
+    return {};
 }
 
 /******************************************************************************
@@ -345,7 +345,7 @@ QString ResourceType::storageTypeString(StorageType type)
         case Directory:
             return storageTypeStr(true, (type == File), true);
         default:
-            return QString();
+            return {};
     }
 }
 
