@@ -1,15 +1,15 @@
 /*
  *  resourcetype.h  -  base class for an alarm calendar resource type
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2019-2021 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2019-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #pragma once
 
-#include <KAlarmCal/KACalendar>
-#include <KAlarmCal/KAEvent>
+#include "kalarmcalendar/kacalendar.h"
+#include "kalarmcalendar/kaevent.h"
 
 #include <QObject>
 #include <QSharedPointer>
@@ -65,7 +65,7 @@ public:
     /** A shared pointer to an Resource object. */
     using Ptr = QSharedPointer<ResourceType>;
 
-    ResourceType()  {}
+    ResourceType() = default;
 
     /** Constructor.
      *  @param temporary  If false, the new instance will be added to the list
@@ -504,5 +504,4 @@ template <class T> const T* ResourceType::resource(const Resource& res)
     return qobject_cast<const T*>(data(res));
 }
 
-
 // vim: et sw=4:
