@@ -1,7 +1,7 @@
 /*
  *  undo.cpp  -  undo/redo facility
  *  Program:  kalarm
- *  SPDX-FileCopyrightText: 2005-2020 David Jarvie <djarvie@kde.org>
+ *  SPDX-FileCopyrightText: 2005-2022 David Jarvie <djarvie@kde.org>
  *
  *  SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -12,10 +12,9 @@
 #include "resourcescalendar.h"
 #include "resources/resources.h"
 #include "lib/messagebox.h"
+#include "kalarmcalendar/alarmtext.h"
 #include "kalarm_debug.h"
 
-#include <KAlarmCal/AlarmText>
-
 #include <KLocalizedString>
 
 #include <QApplication>
@@ -35,11 +34,11 @@ class UndoItem
         virtual Operation  operation() const = 0;
         virtual QString    actionText() const    { return !mName.isEmpty() ? mName : defaultActionText(); }
         virtual QString    defaultActionText() const = 0;
-        virtual QString    description() const   { return QString(); }
-        virtual QString    eventID() const       { return QString(); }
-        virtual QString    oldEventID() const    { return QString(); }
-        virtual QString    newEventID() const    { return QString(); }
-        virtual Resource   resource() const      { return Resource(); }
+        virtual QString    description() const   { return {}; }
+        virtual QString    eventID() const       { return {}; }
+        virtual QString    oldEventID() const    { return {}; }
+        virtual QString    newEventID() const    { return {}; }
+        virtual Resource   resource() const      { return {}; }
         int                id() const            { return mId; }
         Undo::Type         type() const          { return mType; }
         void               setType(Undo::Type t) { mType = t; }
@@ -77,6 +76,8 @@ class UndoMultiBase : public UndoItem
                 : UndoItem(t, name), mUndos(new Undo::List) {}
         UndoMultiBase(Undo::Type t, Undo::List* undos, const QString& name)
                 : UndoItem(t, name), mUndos(undos) {}
+        UndoMultiBase(const UndoMultiBase&) = delete;
+        UndoMultiBase& operator=(const UndoMultiBase&) = delete;
         ~UndoMultiBase() override { delete mUndos; }
         const Undo::List* undos() const         { return mUndos; }
     protected:
@@ -125,6 +126,8 @@ class UndoEdit : public UndoItem
     public:
         UndoEdit(Undo::Type, const KAEvent& oldEvent, const QString& newEventID,
                  const Resource&, const QStringList& dontShowErrors, const QString& description);
+        UndoEdit(const UndoEdit&) = delete;
+        UndoEdit& operator=(const UndoEdit&) = delete;
         ~UndoEdit() override;
         Operation          operation() const override     { return EDIT; }
         QString            defaultActionText() const override;
@@ -150,6 +153,8 @@ class UndoDelete : public UndoItem
     public:
         UndoDelete(Undo::Type, const Undo::Event&, const QString& name = QString());
         UndoDelete(Undo::Type, const KAEvent&, const Resource&, const QStringList& dontShowErrors, const QString& name = QString());
+        UndoDelete(const UndoDelete&) = delete;
+        UndoDelete& operator=(const UndoDelete&) = delete;
         ~UndoDelete() override;
         Operation          operation() const override     { return DELETE; }
         QString            defaultActionText() const override;
@@ -158,7 +163,7 @@ class UndoDelete : public UndoItem
         QString            eventID() const override       { return mEvent->id(); }
         QString            oldEventID() const override    { return mEvent->id(); }
         UndoItem*          restore() override;
-        KAEvent*           event() const                         { return mEvent; }
+        KAEvent*           event() const                  { return mEvent; }
         void               dumpDebug() const override;
     protected:
         virtual UndoItem*  createRedo(const KAEvent&, const Resource&);
@@ -668,7 +673,7 @@ QString UndoItem::addDeleteActionText(CalEvent::Type calendar, bool add)
         default:
             break;
     }
-    return QString();
+    return {};
 }
 
 /******************************************************************************
@@ -1048,7 +1053,7 @@ QString UndoEdit::defaultActionText() const
         default:
             break;
     }
-    return QString();
+    return {};
 }
 
 /******************************************************************************
@@ -1246,7 +1251,7 @@ UndoItem* UndoDeletes::createRedo(Undo::List* undos)
 QString UndoDeletes::defaultActionText() const
 {
     if (mUndos->isEmpty())
-        return QString();
+        return {};
     for (const UndoItem* item : std::as_const(*mUndos))
     {
         switch (item->calendar())
@@ -1258,7 +1263,7 @@ QString UndoDeletes::defaultActionText() const
             case CalEvent::ARCHIVED:
                 break;    // check if they are ALL archived
             default:
-                return QString();
+                return {};
         }
     }
     return i18nc("@info", "Delete multiple archived alarms");
